# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`tftpboot`](#tftpboot): class tftpboot  Sets up a tftpboot server.
* [`tftpboot::config`](#tftpboot--config): Configuration class called from tftpboot.
* [`tftpboot::config::bios`](#tftpboot--config--bios): Configuration class called from tftpboot::config.
* [`tftpboot::config::efi`](#tftpboot--config--efi): Configuration class called from tftpboot::config.

### Defined types

* [`tftpboot::assign_host`](#tftpboot--assign_host): define tftpboot:assign_host   Sets up links to `templates/$model` in the `tftpboot.cfg/`  sub-directory of `$::tftpboot::install_root_dir`
* [`tftpboot::assign_host_efi`](#tftpboot--assign_host_efi): define tftpboot:assign_host_efi   Sets up links to `templates/$model` in the `efi/`  sub-directory of `$::tftpboot::install_root_dir`
* [`tftpboot::generic_model`](#tftpboot--generic_model): define tftpboot:generic_model  This define is for generic entries used to PXEboot a server. The generic entries will be written to `$::tftpbo
* [`tftpboot::linux_model`](#tftpboot--linux_model): Add a TFTPBoot Linux model entry for BIOS boot
* [`tftpboot::linux_model_efi`](#tftpboot--linux_model_efi): Add a TFTPBoot Linux model entry for UEFI boot

### Functions

* [`tftpboot::get_os_base_filenames`](#tftpboot--get_os_base_filenames): Returns an array of base filenames for all OS PXEboot files contained in the input Hash

## Classes

### <a name="tftpboot"></a>`tftpboot`

class tftpboot

Sets up a tftpboot server.

#### Parameters

The following parameters are available in the `tftpboot` class:

* [`tftpboot_root_dir`](#-tftpboot--tftpboot_root_dir)
* [`linux_install_dir`](#-tftpboot--linux_install_dir)
* [`trusted_nets`](#-tftpboot--trusted_nets)
* [`rsync_enabled`](#-tftpboot--rsync_enabled)
* [`rsync_source`](#-tftpboot--rsync_source)
* [`rsync_server`](#-tftpboot--rsync_server)
* [`rsync_timeout`](#-tftpboot--rsync_timeout)
* [`purge_configs`](#-tftpboot--purge_configs)
* [`use_os_files`](#-tftpboot--use_os_files)
* [`os_file_info`](#-tftpboot--os_file_info)
* [`package_ensure`](#-tftpboot--package_ensure)

##### <a name="-tftpboot--tftpboot_root_dir"></a>`tftpboot_root_dir`

Data type: `Stdlib::Absolutepath`

The root directory of tftboot.

Default value: `'/var/lib/tftpboot'`

##### <a name="-tftpboot--linux_install_dir"></a>`linux_install_dir`

Data type: `String`

The name of a sub-directory of `$tftpboot_root_dir` (relative path) that
contains files used to PXEboot a server.

Default value: `'linux-install'`

##### <a name="-tftpboot--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

See `only_from` in `xinetd.conf(5)`.

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1', '::1'] })`

##### <a name="-tftpboot--rsync_enabled"></a>`rsync_enabled`

Data type: `Boolean`

Whether to use rsync to efficiently pull initial boot files from a central
location (i.e., the rsync server) and install them into
`$tftpboot_root_dir`.  When set to `false`, you must provide some other
mechanism to install the initial boot files into
`$tftpboot_root_dir`.

Default value: `true`

##### <a name="-tftpboot--rsync_source"></a>`rsync_source`

Data type: `String`

The source of the content to be rsync'd.

Default value: `"tftpboot_${::environment}_${facts['os']['name']}/*"`

##### <a name="-tftpboot--rsync_server"></a>`rsync_server`

Data type: `String`

The rsync server FQDN from which to pull the tftpboot configuration. This
should contain the entire PXEboot hierarchy if you wish to use this to
PXEboot servers.

Default value: `simplib::lookup('simp_options::rsync::server',  { 'default_value' => '127.0.0.1' })`

##### <a name="-tftpboot--rsync_timeout"></a>`rsync_timeout`

Data type: `Integer`

The connection timeout for the rsync connections.

Default value: `simplib::lookup('simp_options::rsync::timeout', { 'default_value' => 2 })`

##### <a name="-tftpboot--purge_configs"></a>`purge_configs`

Data type: `Boolean`

Determines if non puppet-managed configuration files in
`$tftpboot_root_dir/$linux_install_dir/pxelinux.cfg` get purged. At this
time, there is no purge mechanism for
`$tftpboot_root_dir/$linux_install_dir/efi`, which contains both
configuration and initial boot files.

Default value: `true`

##### <a name="-tftpboot--use_os_files"></a>`use_os_files`

Data type: `Boolean`

If `true`, use the OS provided syslinux and grub packages to obtain the
initial boot files (e.g., `pxelinux.0`, `menu.c32`, `grub.efi`,
`grubx64.efi`, `shim.efi`).

Default value: `true`

##### <a name="-tftpboot--os_file_info"></a>`os_file_info`

Data type: `Hash`

Hash of Hashes containing the mapping of OS packages to initial boot files.
The outer Hash key is either 'bios' or 'efi', corresponding to BIOS or UEFI
boot, respectively. The inner Hash is a Hash of Arrays. Each inner Hash key
is an OS package.  Each inner Hash value is the list of PXEboot files
provided by the named package.  See the module data for specifics.

##### <a name="-tftpboot--package_ensure"></a>`package_ensure`

Data type: `String`

The `ensure` setting of packages to be installed.

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="tftpboot--config"></a>`tftpboot::config`

Configuration class called from tftpboot.

### <a name="tftpboot--config--bios"></a>`tftpboot::config::bios`

Configuration class called from tftpboot::config.

### <a name="tftpboot--config--efi"></a>`tftpboot::config::efi`

Configuration class called from tftpboot::config.

## Defined types

### <a name="tftpboot--assign_host"></a>`tftpboot::assign_host`

define tftpboot:assign_host

 Sets up links to `templates/$model` in the `tftpboot.cfg/`
 sub-directory of `$::tftpboot::install_root_dir`

#### Parameters

The following parameters are available in the `tftpboot::assign_host` defined type:

* [`model`](#-tftpboot--assign_host--model)
* [`ensure`](#-tftpboot--assign_host--ensure)

##### <a name="-tftpboot--assign_host--model"></a>`model`

Data type: `String`

Should be the name of a previously defined model

##### <a name="-tftpboot--assign_host--ensure"></a>`ensure`

Data type: `Enum['absent','link']`

Ensure for files managed.

Default value: `'link'`

### <a name="tftpboot--assign_host_efi"></a>`tftpboot::assign_host_efi`

define tftpboot:assign_host_efi

 Sets up links to `templates/$model` in the `efi/`
 sub-directory of `$::tftpboot::install_root_dir`

#### Parameters

The following parameters are available in the `tftpboot::assign_host_efi` defined type:

* [`legacy_grub`](#-tftpboot--assign_host_efi--legacy_grub)
* [`model`](#-tftpboot--assign_host_efi--model)
* [`ensure`](#-tftpboot--assign_host_efi--ensure)

##### <a name="-tftpboot--assign_host_efi--legacy_grub"></a>`legacy_grub`

Data type: `Boolean`

Whether this host uses legacy grub.

Default value: `false`

##### <a name="-tftpboot--assign_host_efi--model"></a>`model`

Data type: `String`

Should be the name of a previously defined model

##### <a name="-tftpboot--assign_host_efi--ensure"></a>`ensure`

Data type: `Enum['absent','link']`

Ensure for files managed.

Default value: `'link'`

### <a name="tftpboot--generic_model"></a>`tftpboot::generic_model`

define tftpboot:generic_model

This define is for generic entries used to PXEboot a server.
The generic entries will be written to
`$::tftpboot::tftpboot_root_dir/pxe-linux/templates`.

== Parameters

#### Parameters

The following parameters are available in the `tftpboot::generic_model` defined type:

* [`content`](#-tftpboot--generic_model--content)
* [`ensure`](#-tftpboot--generic_model--ensure)

##### <a name="-tftpboot--generic_model--content"></a>`content`

Data type: `String`

The actual verbatim content of the entry.

##### <a name="-tftpboot--generic_model--ensure"></a>`ensure`

Data type: `Enum['absent','present']`

Ensure for files managed.

Default value: `'present'`

### <a name="tftpboot--linux_model"></a>`tftpboot::linux_model`

Add a TFTPBoot Linux model entry for BIOS boot

#### Parameters

The following parameters are available in the `tftpboot::linux_model` defined type:

* [`kernel`](#-tftpboot--linux_model--kernel)
* [`initrd`](#-tftpboot--linux_model--initrd)
* [`ks`](#-tftpboot--linux_model--ks)
* [`extra`](#-tftpboot--linux_model--extra)
* [`ensure`](#-tftpboot--linux_model--ensure)
* [`fips`](#-tftpboot--linux_model--fips)

##### <a name="-tftpboot--linux_model--kernel"></a>`kernel`

Data type: `String`

The location of the kernel within the tftpboot tree.
Path is relative to `$::tftpboot::install_root_dir`.

##### <a name="-tftpboot--linux_model--initrd"></a>`initrd`

Data type: `String`

The location of the initial RAM disk within the tftpboot tree.
Path is relative to `$::tftpboot::install_root_dir`.

##### <a name="-tftpboot--linux_model--ks"></a>`ks`

Data type: `String`

The full URL to the location of the kickstart file.

##### <a name="-tftpboot--linux_model--extra"></a>`extra`

Data type: `Optional[String]`

Any other kernel parameters that you would like to pass at boot.
You will probably want this to be
'ksdevice=bootif\nIPAPPEND 2' if you are kickstarting
systems.

Default value: `undef`

##### <a name="-tftpboot--linux_model--ensure"></a>`ensure`

Data type: `Enum['absent','present']`

Set or delete this entry.  Options: ['absent'|'present']

Default value: `'present'`

##### <a name="-tftpboot--linux_model--fips"></a>`fips`

Data type: `Boolean`

If true, enables FIPS in the kernel parameters at PXE
time. This *may not work* with all initrd images.

Default value: `false`

### <a name="tftpboot--linux_model_efi"></a>`tftpboot::linux_model_efi`

Add a TFTPBoot Linux model entry for UEFI boot

#### Parameters

The following parameters are available in the `tftpboot::linux_model_efi` defined type:

* [`kernel`](#-tftpboot--linux_model_efi--kernel)
* [`initrd`](#-tftpboot--linux_model_efi--initrd)
* [`ks`](#-tftpboot--linux_model_efi--ks)
* [`extra`](#-tftpboot--linux_model_efi--extra)
* [`ensure`](#-tftpboot--linux_model_efi--ensure)
* [`fips`](#-tftpboot--linux_model_efi--fips)
* [`legacy_grub`](#-tftpboot--linux_model_efi--legacy_grub)

##### <a name="-tftpboot--linux_model_efi--kernel"></a>`kernel`

Data type: `String`

The location of the kernel within the tftpboot tree.
Path is relative to `$::tftpboot::install_root_dir`.

##### <a name="-tftpboot--linux_model_efi--initrd"></a>`initrd`

Data type: `String`

The location of the initial RAM disk within the tftpboot tree.
Path is relative to `$::tftpboot::install_root_dir`.

##### <a name="-tftpboot--linux_model_efi--ks"></a>`ks`

Data type: `String`

The full URL to the location of the kickstart file.

##### <a name="-tftpboot--linux_model_efi--extra"></a>`extra`

Data type: `Optional[String]`

Any other kernel parameters that you would like to pass at boot.
You will probably want this to be
'ksdevice=bootif\nIPAPPEND 2' if you are kickstarting
systems.

Default value: `undef`

##### <a name="-tftpboot--linux_model_efi--ensure"></a>`ensure`

Data type: `Enum['absent','present']`

Set or delete this entry.  Options: ['absent'|'present']

Default value: `'present'`

##### <a name="-tftpboot--linux_model_efi--fips"></a>`fips`

Data type: `Boolean`

If true, enables FIPS in the kernel parameters at PXE
time. This *may not work* with all initrd images.

Default value: `false`

##### <a name="-tftpboot--linux_model_efi--legacy_grub"></a>`legacy_grub`

Data type: `Boolean`

Whether this host uses legacy grub.

Default value: `false`

## Functions

### <a name="tftpboot--get_os_base_filenames"></a>`tftpboot::get_os_base_filenames`

Type: Puppet Language

Returns an array of base filenames for all OS PXEboot files contained
in the input Hash

#### `tftpboot::get_os_base_filenames(Hash $os_file_info)`

Returns an array of base filenames for all OS PXEboot files contained
in the input Hash

Returns: `Array` Array of base filenames

##### `os_file_info`

Data type: `Hash`

Hash of Hashes.  The outer Hash key is either
'bios' or 'efi', corresponding to BIOS or UEFI boot, respectively.
The inner Hash is a Hash of Arrays. Each inner Hash key is an
OS package.  Each inner Hash value is the list of PXEboot files
provided by the named package.  See the module data for specifics.

